MethodChannelLocalePlus class

Inheritance

Constructors

MethodChannelLocalePlus()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAmSymbol() → Future<String?>
override
getDateFormatPattern() → Future<String?>
override
getDecimalSeparator() → Future<String?>
override
getFirstDayOfWeek() → Future<int?>
override
getGroupingSeparator() → Future<String?>
override
getLanguageCode() → Future<String?>
override
getPmSymbol() → Future<String?>
override
getRegionCode() → Future<String?>
override
getSecondsFromGMT() → Future<int?>
override
getTimeZoneIdentifier() → Future<String?>
override
is24HourTime() → Future<bool?>
override
isUsingSamsungKeyboard() → Future<bool?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
usesMetricSystem() → Future<bool?>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited