LocalePlusPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • LocalePlusPlatform
Implementers

Constructors

LocalePlusPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAmSymbol() → Future<String?>
getDateFormatPattern() → Future<String?>
getDecimalSeparator() → Future<String?>
getFirstDayOfWeek() → Future<int?>
getGroupingSeparator() → Future<String?>
getLanguageCode() → Future<String?>
getPmSymbol() → Future<String?>
getRegionCode() → Future<String?>
getSecondsFromGMT() → Future<int?>
getTimeZoneIdentifier() → Future<String?>
is24HourTime() → Future<bool?>
isUsingSamsungKeyboard() → Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
usesMetricSystem() → Future<bool?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ LocalePlusPlatform
getter/setter pair